Band

Enum Band 

pub enum Band {
    Title(Vec<Element>),
    PageHeader(Vec<Element>),
    ColumnHeader(Vec<Element>),
    Detail(Vec<Element>),
    ColumnFooter(Vec<Element>),
    PageFooter(Vec<Element>),
    Summary(Vec<Element>),
    Custom(String, Vec<Element>),
}
Band is a section of a document(Title, PageHeader, ColumnHeader, Detail, ColumnFooter, PageFooter, Summary).

Each band contains a list of elements (Text, Table, List, Image, Hyperlink…).

Bands are used to organize the content of a document.

Documents in general have a predefined set of bands, but custom bands can be created.

PageHeader, Detail, PageFooter are the most common bands and is used to display the header, main content, and footer of documents of any type(XML, CSV, JSON…).

The logic to handle custom bands is up to the user/file format

Variants



Title(Vec<Element>)

This band happens only once at the beginning of the document and is not repeated.



PageHeader(Vec<Element>)

This band happens only once at the beginning of the document and is repeated every page. Title and summary bands are mutually exclusive The PageHeader band is also used to display the header of documents of any type, commonly used in conjunction with the Detail and PageFooter band



ColumnHeader(Vec<Element>)

This band is printed at the beginning of each detail section. Usually, labels containing the column names of a tabular report are inserted in this band.



Detail(Vec<Element>)

This band is repeated for every single read record. It contains the main content of the document The detail band is the most common band and is used to display the main content of the document of any type



ColumnFooter(Vec<Element>)

This band is printed at the end of each detail section.



PageFooter(Vec<Element>)

This band happens only once at the end of the document and is repeated every page.



Summary(Vec<Element>)

This band happens only once at the end of the document and is not repeated.



Custom(String, Vec<Element>)

This is a custom band, receiving a unique name and a list of elements The logic to handle this band is up to the user/file format

Implementations

Source

impl Band

pub fn elements(&self) -> &Vec<Element>